/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.orverw.db.rmi;

import java.rmi.RemoteException;
import java.util.Date;

import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Font;

import de.willuhn.datasource.rmi.DBIterator;
import de.willuhn.datasource.rmi.DBObject;

/**
 * Interface f&uuml; die Ordnertablle
 *
 * <pre>
 * CREATE TABLE ordner (
 *   id NUMERIC default UNIQUEKEY('ordner'),
 *   title varchar(80) NOT NULL,
 *   titleFont varchar(80),
 *   titleColor int,
 *   titleAlignmnet int,
 *   content varchar(300),
 *   contentFont varchar(80),
 *   contentColor int,
 *   contentAlignmnet int,
 *   footer varchar(100),
 *   footerFont varchar(80),
 *   footerColor int,
 *   footerAlignmnet int,
 *   labelBackground int,
 *   horizontalBarVisible boolean default true,
 *   horizontalBarColor int,
 *   idVisible boolean default true,
 *   registerIndexFont varchar(80),
 *   registerIndexColor int,
 *   registerIndexBackground int,
 *   registerContentFont varchar(80),
 *   registerContentColor int,
 *   registerContentBackground int,
 *   width int,
 *   lastSaveDate date,
 *   UNIQUE (id),
 *   PRIMARY KEY (id)
 * );
 * </pre>
 *
 * @author munstfr
 * @version 1.0
 */
@SuppressWarnings("PMD.ExcessivePublicCount")
public interface Ordner extends DBObject {

    /**
     * @return die Linienfarbe
     * @throws RemoteException
     */
    Color getBarColor() throws RemoteException;

    /**
     * @return den Text des Hauptbereiches
     * @throws RemoteException
     */
    String getContent() throws RemoteException;

    /**
     * @return die Ausrichtugn des Hauptbereiches
     * @throws RemoteException
     */
    int getContentAlignment() throws RemoteException;

    /**
     * @return die Textfarbe des Hauptbereiches
     * @throws RemoteException
     */
    Color getContentColor() throws RemoteException;

    /**
     * @return den Schrifttype des Hauptbereiches
     * @throws RemoteException
     */
    Font getContentFont() throws RemoteException;

    /**
     * @return das Datum der letzten &Auml;nderung
     * @throws RemoteException
     */
    Date getDate() throws RemoteException;

    /**
     * @return des Text des Fu&szlig;bereiches
     * @throws RemoteException
     */
    String getFooter() throws RemoteException;

    /**
     * @return die Ausrichtung des Fu&szlig;bereiches
     * @throws RemoteException
     */
    int getFooterAlignment() throws RemoteException;

    /**
     * @return die Textfarbe des Fu&szlig;bereiches
     * @throws RemoteException
     */
    Color getFooterColor() throws RemoteException;

    /**
     * @return den Schrifttyp des Fu&szlig;bereiches
     * @throws RemoteException
     */
    Font getFooterFont() throws RemoteException;

    /**
     * @return Das Register
     * @throws RemoteException
     */
    DBIterator<Register> getInhaltsverzeichniss() throws RemoteException;

    /**
     * @return die Hintergrungfarbe des Labels
     * @throws RemoteException
     */
    Color getLabelBackground() throws RemoteException;

    /**
     * @return die Hintergrundfarbe der Registerbeschreibungsfelder
     * @throws RemoteException
     */
    Color getRegisterContentBackground() throws RemoteException;

    /**
     * @return die Textfarbe der Registerbeschreibungsfelder
     * @throws RemoteException
     */
    Color getRegisterContentColor() throws RemoteException;

    /**
     * @return den Schrifttyp der Registerbeschreibungsfelder
     * @throws RemoteException
     */
    Font getRegisterContentFont() throws RemoteException;

    /**
     * @return die Hintergrundfarbe der Registerindexfelder
     * @throws RemoteException
     */
    Color getRegisterIndexBackground() throws RemoteException;

    /**
     * @return die Textfarbe der Registerindexfelder
     * @throws RemoteException
     */
    Color getRegisterIndexColor() throws RemoteException;

    /**
     * @return den Schrifttyp der Registerindexfelder
     * @throws RemoteException
     */
    Font getRegisterIndexFont() throws RemoteException;

    /**
     * @return den Text des Titelfeldes
     * @throws RemoteException
     */
    String getTitel() throws RemoteException;

    /**
     * @return die Ausrichtung des Titelfeldes
     * @throws RemoteException
     */
    int getTitelAlignment() throws RemoteException;

    /**
     * @return die Textfarbe des Titelfeldes
     * @throws RemoteException
     */
    Color getTitelColor() throws RemoteException;

    /**
     * @return den Schifttyp des Titelfeldes
     * @throws RemoteException
     */
    Font getTitelFont() throws RemoteException;

    /**
     * @return die Breite des Labels
     * @throws RemoteException
     */
    Integer getWidth() throws RemoteException;

    /**
     * @return die Sichbarkeit der Linien
     * @throws RemoteException
     */
    boolean isBarVisible() throws RemoteException;

    /**
     * @return die Sichbarkeit des ID Feldes
     * @throws RemoteException
     */
    boolean isIdVisible() throws RemoteException;

    /**
     * L&auml;d die gespeicherten Defaultwerte aus
     *
     * @see de.frankmuenster.jameica.orverw.Settings
     * @throws RemoteException
     */
    void loadDefaults() throws RemoteException;

    /**
     * Setzt die Farbe der Linien
     *
     * @param color
     *            die Farbe der Linien
     * @throws RemoteException
     */
    void setBarColor(Color color) throws RemoteException;

    /**
     * Setzt die Sichbarkeit der Linien
     *
     * @param visible
     *            die Sichbarkeit der Linien
     * @throws RemoteException
     */
    void setBarVisible(boolean visible) throws RemoteException;

    /**
     * Setzt den Text des Hauptfeldes
     *
     * @param inhalt
     *            den Text des Hauptfeldes
     * @throws RemoteException
     */
    void setContent(String inhalt) throws RemoteException;

    /**
     * Setzt die Ausrichtung den Hauptfeldes (SWT.LEFT, SWT.CENTER, SWT.RIGHT)
     *
     * @param alignment
     *            die Ausrichtung den Hauptfeldes
     * @throws RemoteException
     */
    void setContentAlignment(int alignment) throws RemoteException;

    /**
     * Setzt die Textfarbe des Hauptfeldes
     *
     * @param color
     *            die Textfarbe des Hauptfeldes
     * @throws RemoteException
     */
    void setContentColor(Color color) throws RemoteException;

    /**
     * Setzt den Schrifttyp des Hauptfeldes
     *
     * @param font
     *            den Schrifttyp des Hauptfeldes
     * @throws RemoteException
     */
    void setContentFont(Font font) throws RemoteException;

    /**
     * Setzt das zuletzt ge&auml;ndert Datum
     *
     * @param datum
     *            das zuletzt ge&auml;ndert Datum
     * @throws RemoteException
     */
    void setDate(Date datum) throws RemoteException;

    /**
     * Setzt den Text des Fu&szlig;bereiches
     *
     * @param fussnote
     *            den Text des Fu&szlig;bereiches
     * @throws RemoteException
     */
    void setFooter(String fussnote) throws RemoteException;

    /**
     * Setzt die Ausrichtung des Fu&szlig;bereiches
     *
     * @param alignment
     *            die Ausrichtung des Fu&szlig;bereiches
     * @throws RemoteException
     */
    void setFooterAlignment(int alignment) throws RemoteException;

    /**
     * Setzt die Textfarbe des Fu&szlig;bereiches
     *
     * @param color
     *            die Textfarbe des Fu&szlig;bereiches
     * @throws RemoteException
     */
    void setFooterColor(Color color) throws RemoteException;

    /**
     * Setzt den Schrifttyp des Fu&szlig;bereiches
     *
     * @param font
     *            den Schrifttyp des Fu&szlig;bereiches
     * @throws RemoteException
     */
    void setFooterFont(Font font) throws RemoteException;

    /**
     * Setzt die Sichbarkeit des ID-Feldes
     *
     * @param visible
     *            die Sichbarkeit des ID-Feldes
     * @throws RemoteException
     */
    void setIdVisible(boolean visible) throws RemoteException;

    /**
     * Setzt die Hintergrundfarbe des Labels
     *
     * @param color
     *            die Hintergrundfarbe des Labels
     * @throws RemoteException
     */
    void setLabelBackground(Color color) throws RemoteException;

    /**
     * Setzt den Hintergrundfarbe der Registerbeschreibungsfelder
     *
     * @param color
     *            den Hintergrundfarbe der Registerbeschreibungsfelder
     * @throws RemoteException
     */
    void setRegisterContentBackground(Color color) throws RemoteException;

    /**
     * Setzt die Textfarbe der Registerbeschreibungsfelder
     *
     * @param color
     *            die Textfarbe der Registerbeschreibungsfelder
     * @throws RemoteException
     */
    void setRegisterContentColor(Color color) throws RemoteException;

    /**
     * Setzt den Schrifttyp der Registerbeschreibungsfelder
     *
     * @param font
     *            den Schrifttyp der Registerbeschreibungsfelder
     * @throws RemoteException
     */
    void setRegisterContentFont(Font font) throws RemoteException;

    /**
     * Setzt den Hintergrundfarbe der Registerindexfelder
     *
     * @param color
     *            den Hintergrundfarbe der Registerindexfelder
     * @throws RemoteException
     */
    void setRegisterIndexBackground(Color color) throws RemoteException;

    /**
     * Setzt die Textfarbe der Registerindexfelder
     *
     * @param color
     *            die Textfarbe der Registerindexfelder
     * @throws RemoteException
     */
    void setRegisterIndexColor(Color color) throws RemoteException;

    /**
     * Setzt den Schrifttyp der Registerindexfelder
     *
     * @param font
     *            den Schrifttyp der Registerindexfelder
     * @throws RemoteException
     */
    void setRegisterIndexFont(Font font) throws RemoteException;

    /**
     * Setzt den Text des Titelfeldes
     *
     * @param titel
     *            den Text des Titelfeldes
     * @throws RemoteException
     */
    void setTitel(String titel) throws RemoteException;

    /**
     * Setzt die Ausrichtung des Titelfeldes
     *
     * @param alignment
     *            die Ausrichtung des Titelfeldes
     * @throws RemoteException
     */
    void setTitelAlignment(int alignment) throws RemoteException;

    /**
     * Setzt die Textfarbe des Titelfeldes
     *
     * @param color
     *            die Textfarbe des Titelfeldes
     * @throws RemoteException
     */
    void setTitelColor(Color color) throws RemoteException;

    /**
     * Setzt den Schirfttyp des Titelfeldes
     *
     * @param font
     *            den Schrifttyp des Titelfeldes
     * @throws RemoteException
     */
    void setTitelFont(Font font) throws RemoteException;

    /**
     * Setzt die Breite des Labels
     *
     * @param width
     *            die Breite des Labels
     * @throws RemoteException
     */
    void setWidth(Integer width) throws RemoteException;
}
