/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.orverw.db.server;

import java.rmi.RemoteException;

import org.apache.commons.lang.StringUtils;

import de.frankmuenster.jameica.orverw.db.rmi.Ordner;
import de.frankmuenster.jameica.orverw.db.rmi.Register;
import de.frankmuenster.jameica.orverw.util.I18N;
import de.willuhn.datasource.db.AbstractDBObject;
import de.willuhn.datasource.rmi.ObjectNotFoundException;
import de.willuhn.logging.Logger;
import de.willuhn.util.ApplicationException;

/**
 * Die Implementierung des Datenbank Interface zu den Registereintr&auml;gen
 *
 * <pre>
 *   id NUMERIC default UNIQUEKEY('inhaltsverzeichniss'),
 *   ordner_id int(4) NOT NULL,
 *   idx varchar(10),
 *   content varchar(80),
 *   position int,
 *   UNIQUE (id), PIMARY KEY (id)
 * </pre>
 *
 * @author Frank Mnster
 */
public class RegisterImpl extends AbstractDBObject implements Register {

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = 6650563945934599214L;

    /**
     * The ordnerID table column name
     */
    private static final String ORDNER_ID = "ordner_id"; //$NON-NLS-1$

    /**
     * @throws RemoteException
     */
    public RegisterImpl() throws RemoteException {
	super();
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#getBeschreibung()
     */
    @Override
    public String getBeschreibung() throws RemoteException {
	return (String) this.getAttribute("content"); //$NON-NLS-1$
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#getIndex()
     */
    @Override
    public String getIndex() throws RemoteException {
	return (String) this.getAttribute("idx"); //$NON-NLS-1$
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#getOrdner()
     */
    @Override
    public Ordner getOrdner() throws RemoteException {
	// Yes, we can cast this directly to Ordner, because
	// getForeignObject(String)
	// contains the mapping for this attribute.
	try {
	    return (Ordner) this.getAttribute(RegisterImpl.ORDNER_ID); // NOPMD
	} catch (final ObjectNotFoundException e) {
	    return null;
	}
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#getOrdnerId()
     */
    @Override
    public int getOrdnerId() throws RemoteException {
	final Integer ordner_id = (Integer) this.getAttribute(RegisterImpl.ORDNER_ID);
	if (ordner_id != null) {
	    return ordner_id; // NOPMD
	}
	return 0;
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#getPosition()
     */
    @Override
    public int getPosition() throws RemoteException {
	final Integer position = (Integer) this.getAttribute("position"); //$NON-NLS-1$
	return position == null ? 0 : position;
    }

    /**
     * @see de.willuhn.datasource.db.AbstractDBObject#getPrimaryAttribute()
     */
    @Override
    public String getPrimaryAttribute() throws RemoteException {
	return "id"; //$NON-NLS-1$
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#setBeschreibung(java.lang.String)
     */
    @Override
    public void setBeschreibung(final String beschreibung) throws RemoteException {
	this.setAttribute("content", beschreibung); //$NON-NLS-1$
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#setIndex(java.lang.String)
     */
    @Override
    public void setIndex(final String index) throws RemoteException {
	this.setAttribute("idx", index); //$NON-NLS-1$
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#setOrdner(
     *      de.frankmuenster.jameica.orverw.db.rmi.Ordner)
     */
    @Override
    public void setOrdner(final Ordner ordner) throws RemoteException {
	// casting wird in foreignObject bernommen
	this.setAttribute(RegisterImpl.ORDNER_ID, ordner);
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#setOrdnerId(int)
     */
    @Override
    public void setOrdnerId(final int orderId) throws RemoteException {
	this.setAttribute(RegisterImpl.ORDNER_ID, orderId);
    }

    /**
     * @see de.frankmuenster.jameica.orverw.db.rmi.Register#setPosition(int)
     */
    @Override
    public void setPosition(final int position) throws RemoteException {
	this.setAttribute("position", position); //$NON-NLS-1$
    }

    /**
     * @see de.willuhn.datasource.db.AbstractDBObject#deleteCheck()
     */
    @Override
    protected void deleteCheck() throws ApplicationException {
	// hier brauchen haben wir nichts zu tun
    }

    /**
     * @see de.willuhn.datasource.db.AbstractDBObject#getForeignObject(java.lang.String)
     */
    @Override
    protected Class<Ordner> getForeignObject(final String field) throws RemoteException {
	// the system is able to resolve foreign keys and loads
	// the according objects automatically. You only have to
	// define which class handles which foreign key.
	if (RegisterImpl.ORDNER_ID.equals(field)) { // NOPMD
	    return Ordner.class; // NOPMD
	}
	return null;
    }

    /**
     * @see de.willuhn.datasource.db.AbstractDBObject#getTableName()
     */
    @Override
    protected String getTableName() {
	return "register"; //$NON-NLS-1$
    }

    /**
     * @see de.willuhn.datasource.db.AbstractDBObject#insertCheck()
     */
    @Override
    protected void insertCheck() throws ApplicationException {
	try {
	    if (this.getIndex() == null) {
		this.setIndex(StringUtils.EMPTY);
	    }
	    if (this.getBeschreibung() == null) {
		this.setBeschreibung(StringUtils.EMPTY);
	    }
	    if (this.getOrdner() == null) {
		throw new ApplicationException(I18N.tr("RegisterImpl.chooseFolder")); //$NON-NLS-1$
	    }
	    if (this.getOrdner().isNewObject()) {
		throw new ApplicationException(I18N.tr("RegisterImpl.saveFolder")); //$NON-NLS-1$
	    }
	} catch (final RemoteException e) {
	    Logger.error(I18N.tr("RegisterImpl.insertCheckFailed"), e); //$NON-NLS-1$
	    throw new ApplicationException(I18N.tr("RegisterImpl.insertCheckFailedMsg"), e); //$NON-NLS-1$
	}
    }

    /**
     * @see de.willuhn.datasource.db.AbstractDBObject#updateCheck()
     */
    @Override
    protected void updateCheck() throws ApplicationException {
	// same as insertCheck
	this.insertCheck();
    }
}
