/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.orverw.gui.controller;

import java.io.File;
import java.io.FileInputStream;

import de.frankmuenster.jameica.orverw.OrdnerVerwaltung;
import de.frankmuenster.jameica.orverw.util.I18N;
import de.willuhn.io.FileFinder;
import de.willuhn.jameica.gui.AbstractControl;
import de.willuhn.jameica.gui.AbstractView;
import de.willuhn.jameica.gui.Part;
import de.willuhn.jameica.gui.parts.FormTextPart;
import de.willuhn.jameica.plugin.AbstractPlugin;
import de.willuhn.jameica.plugin.Manifest;
import de.willuhn.jameica.system.Application;
import de.willuhn.jameica.util.InfoReader;
import de.willuhn.logging.Logger;

/**
 * Controller f&uuml;r den Lizenzinformationen Dialog
 *
 * Basiert auf dem
 * {@link de.willuhn.jameica.gui.internal.controller#LincenseControl}
 *
 * @author Frank Mnster
 *
 */
public class LicenseControl extends AbstractControl {

    /**
     * Zeilenvorschub
     */
    public static final String LINE_BREAK = "<br/>"; //$NON-NLS-1$

    /**
     * FormTextPart um den Text schn formatieren zu knnen
     */
    private transient FormTextPart libList;

    /**
     * Standart Konstruktor liefert ein LincenceControl object
     *
     * @param view
     *            die View, f&uuml;r die dieser LicenceControl zustndig ist
     */
    public LicenseControl(final AbstractView view) {
	super(view);
    }

    /**
     * Liefert eine Liste mit allen direkt von jameica.qrscanner verwendeten
     * Komponenten.
     *
     * @return Liste der Komponenten.
     */
    @SuppressWarnings({ "PMD.AvoidInstantiatingObjectsInLoops", "PMD.AvoidCatchingGenericException" })
    public Part getLibList() {
	if (this.libList == null) {

	    final AbstractPlugin plugin = Application.getPluginLoader().getPlugin(OrdnerVerwaltung.class);

	    final StringBuilder builder = new StringBuilder();
	    final Manifest manifest = plugin.getManifest();

	    builder.append("<form><p><span color=\"header\" font=\"header\">") //$NON-NLS-1$
		    .append(I18N.tr("_appName")).append("</span></p>"); //$NON-NLS-1$//$NON-NLS-2$
	    if (manifest != null) {
		builder.append("<p>"); //$NON-NLS-1$
		builder.append(manifest.getDescription());
		builder.append(LicenseControl.LINE_BREAK + manifest.getHomepage());
		builder.append(LicenseControl.LINE_BREAK + manifest.getLicense());
		builder.append("</p>"); //$NON-NLS-1$
	    }

	    builder.append("<p><br/><span color=\"header\" font=\"header\">") //$NON-NLS-1$
		    .append(I18N.tr("LicenseControl.usedComponents")) //$NON-NLS-1$
		    .append("</span></p>"); //$NON-NLS-1$
	    final String path = plugin.getManifest().getPluginDir();

	    final FileFinder finder = new FileFinder(new File(path + "/lib")); //$NON-NLS-1$
	    finder.matches(".*?info\\.xml$"); //$NON-NLS-1$
	    final File[] infos = finder.findRecursive();
	    for (int i = 0; i < infos.length; ++i) {
		if (!infos[i].isFile() || !infos[i].canRead()) {
		    Logger.warn("Unable to read " + infos[i] + ", skipping"); //$NON-NLS-1$ //$NON-NLS-2$
		    continue;
		}

		try {
		    final InfoReader infoReader = new InfoReader(new FileInputStream(infos[i]));
		    builder.append("<p><b>").append(infoReader.getName()).append("</b>"); //$NON-NLS-1$ //$NON-NLS-2$
		    builder.append(LicenseControl.LINE_BREAK).append(infoReader.getDescription());
		    builder.append(LicenseControl.LINE_BREAK).append(infoReader.getUrl());
		    builder.append(LicenseControl.LINE_BREAK).append(infoReader.getLicense());
		    builder.append(" </p>"); //$NON-NLS-1$
		} catch (final Exception e) {
		    Logger.error(I18N.tr("LicenseControl.libInfoParseError") + infos[0], e); //$NON-NLS-1$

		}
	    }
	    builder.append("</form>"); //$NON-NLS-1$

	    this.libList = new FormTextPart(builder.toString());
	}

	return this.libList;
    }
}
