/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.jameica.orverw.gui.controller;

import java.rmi.RemoteException;

import de.frankmuenster.jameica.orverw.gui.action.OrdnerNewAction;
import de.frankmuenster.jameica.orverw.gui.action.OrdnerOpenAction;
import de.frankmuenster.jameica.orverw.gui.action.ViewSettingsAction;
import de.frankmuenster.jameica.orverw.gui.menu.OrdnerTableMenu;
import de.frankmuenster.jameica.orverw.parts.OrdnerTablePart;
import de.frankmuenster.jameica.orverw.util.I18N;
import de.willuhn.jameica.gui.AbstractControl;
import de.willuhn.jameica.gui.AbstractView;
import de.willuhn.jameica.gui.Action;
import de.willuhn.jameica.gui.parts.Button;
import de.willuhn.jameica.gui.parts.TablePart;

/**
 * Kontroller f&uuml; die Ordner&uuml;bersicht
 *
 * @author Frank Mnster
 *
 */
public class OrdnerListViewController extends AbstractControl {

    /**
     * Die Ordner-Tabelle
     */
    private transient TablePart ordnerTabelle;

    /**
     * Button zum erstellen eines neuen Ordners
     */
    private transient Button neuerOrdnerButton;

    /**
     * Einstellungs Button
     */
    private transient Button settinsgButton;

    /**
     * Kontroller-Konstruktor
     *
     * @param view
     */
    public OrdnerListViewController(final AbstractView view) {
	super(view);
    }

    /**
     * Liefert einen 'Neuen Ordner' Button.
     *
     * @return Button zum erstellen eines neuen Ordners
     */
    public Button getNeuerOrdner() {
	if (this.neuerOrdnerButton == null) {

	    final Action action = new OrdnerNewAction();
	    this.neuerOrdnerButton = new Button(I18N.tr("OrdnerListViewController.newFolderBtn"), action, null, false, //$NON-NLS-1$
		    "scanner-icon.png"); //$NON-NLS-1$
	    this.neuerOrdnerButton.setEnabled(true);
	}
	return this.neuerOrdnerButton;

    }

    /**
     * Liefert das Ordner-Tabelle-Part Objekt
     *
     * @return die Ordner-Tabelle
     * @throws RemoteException
     */
    public TablePart getOrdnerTabelle() throws RemoteException {
	if (this.ordnerTabelle == null) {

	    this.ordnerTabelle = new OrdnerTablePart(new OrdnerOpenAction());
	    this.ordnerTabelle.setContextMenu(new OrdnerTableMenu());
	}
	return this.ordnerTabelle;
    }

    /**
     * Liefert einen 'Einstellung' Button.
     *
     * @return Button zum erstellen eines neuen Ordners
     */
    public Button getSettings() {
	if (this.settinsgButton == null) {
	    final Action action = new ViewSettingsAction();
	    this.settinsgButton = new Button(I18N.tr("OrdnerListViewController.settingsBtn"), action, null, false, //$NON-NLS-1$
		    "scanner-icon.png"); //$NON-NLS-1$
	    this.settinsgButton.setEnabled(true);
	}
	return this.settinsgButton;
    }
}
