/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.jameica.orverw.gui.input;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Font;

/**
 * Ein sch&ouml;nes Input zrur Auswahl von Schift und Schriftfarbe sowie
 * Hintergrundfarben eines Texteingabefeldes zum Beispiel.
 *
 * @author Frank Mnster
 *
 */
public class TextStyle {

    /**
     * Die Schriftart
     */
    private Font font;
    /**
     * Der Textfarbe
     */
    private Color textColor;
    /**
     * Die Hintergrundfarbe
     */
    private Color backgroundColor;
    /**
     * Die Textausrichtung
     */
    private int alignment;

    /**
     * Der Standartkonstruktor benutzt die Defaultwerte f&uuml; die Schift und
     * die Farben definiert von Jameica
     * 
     */
    public TextStyle() {
	this(de.willuhn.jameica.gui.util.Font.DEFAULT.getSWTFont(), SWT.LEFT,
		de.willuhn.jameica.gui.util.Color.FOREGROUND.getSWTColor(),
		de.willuhn.jameica.gui.util.Color.BACKGROUND.getSWTColor());
    }

    /**
     * Ein Konstruktor bei dem alle Scrifteigenschaften angegeben werden. Falsl
     * null angegeben wird, wird der Jameica-Standartwert verwendet.
     * 
     * @param font
     *            Der Schrifttyp
     * @param alignment
     *            Die Textausrichtung
     * @param textColor
     *            die Textfarbe
     * @param backgroundColor
     *            Die Hindergrundfarbe
     */
    public TextStyle(final Font font, final int alignment, final Color textColor, final Color backgroundColor) {

	if (font == null) {
	    this.font = de.willuhn.jameica.gui.util.Font.DEFAULT.getSWTFont();
	} else {
	    this.font = font;
	}
	checkAlignment(alignment);
	if (textColor == null) {
	    this.textColor = de.willuhn.jameica.gui.util.Color.FOREGROUND.getSWTColor();
	} else {
	    this.textColor = textColor;
	}
	if (backgroundColor == null) {
	    this.backgroundColor = de.willuhn.jameica.gui.util.Color.BACKGROUND.getSWTColor();
	} else {
	    this.backgroundColor = backgroundColor;
	}

    }

    /**
     * @return alignment
     */
    public int getAlignment() {
	return this.alignment;
    }

    /**
     * @return backgroundColor
     */
    public Color getBackgroundColor() {
	return this.backgroundColor;
    }

    /**
     * @return font
     */
    public Font getFont() {
	return this.font;
    }

    /**
     * @return textColor
     */
    public Color getTextColor() {
	return this.textColor;
    }

    /**
     * Setzt die Textausrichtung.
     * 
     * @param alignment
     *            die Textausrichtung. Erlaubte Werte: SWT.LEFT, SWT.CENTER und
     *            SWT.RIGHT. Bei Eingabe anderer Werte wir die Ausrichtung auf
     *            SWT.LEFT gesetzt.
     */
    public void setAlignment(final int alignment) {
	this.alignment = alignment;
    }

    /**
     * @param backgroundColor
     *            das zu setzende Objekt backgroundColor
     */
    public void setBackgroundColor(final Color backgroundColor) {
	if (backgroundColor != null) {
	    this.backgroundColor = backgroundColor;
	}
    }

    /**
     * @param font
     *            das zu setzende Objekt font
     */
    public void setFont(final Font font) {
	if (font != null) {
	    this.font = font;
	}
    }

    /**
     * @param textColor
     *            das zu setzende Objekt textColor
     */
    public void setTextColor(final Color textColor) {
	if (textColor != null) {
	    this.textColor = textColor;
	}
    }

    private void checkAlignment(final int alignment) {
	switch (alignment) {
	case SWT.LEFT:
	    this.alignment = SWT.LEFT;
	    break;
	case SWT.CENTER:
	    this.alignment = SWT.CENTER;
	    break;
	case SWT.RIGHT:
	    this.alignment = SWT.RIGHT;
	    break;
	default:
	    this.alignment = SWT.LEFT;
	    break;
	}
    }

}
