/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.jameica.orverw.gui.menu;

import java.rmi.RemoteException;
import java.util.List;

import de.frankmuenster.jameica.orverw.Settings;
import de.frankmuenster.jameica.orverw.db.rmi.Register;
import de.frankmuenster.jameica.orverw.db.server.RegisterImpl;
import de.frankmuenster.jameica.orverw.gui.controller.OrdnerBearbeitenController;
import de.frankmuenster.jameica.orverw.util.I18N;
import de.willuhn.datasource.rmi.DBService;
import de.willuhn.jameica.gui.Action;
import de.willuhn.jameica.gui.parts.CheckedContextMenuItem;
import de.willuhn.jameica.gui.parts.ContextMenu;
import de.willuhn.jameica.gui.parts.TablePart;
import de.willuhn.util.ApplicationException;

/**
 * Kontextmen&uuml; der Registertabelle
 *
 * @author Frank Mnster
 *
 */
public class RegisterTableMenu extends ContextMenu {

    /**
     * Kontroller zum Bearbeiten von Ordner
     */
    private final transient OrdnerBearbeitenController controller;

    /**
     * Konstruktor f&uuml;r das Kontextmen&uuml; der Registertabelle
     * 
     * @param obc
     *            der Kontroller zum Bearbeiten von Ordner
     */
    public RegisterTableMenu(final OrdnerBearbeitenController obc) {

	super();
	this.controller = obc;

	// CheckedContextMenuItems will be disabled, if the user clicks into
	// an empty space of the table
	addItem(new CheckedContextMenuItem(I18N.tr("RegisterTableMenu.addLine"), new Action() { //$NON-NLS-1$

	    /**
	     * @see de.willuhn.jameica.gui.Action#handleAction(java.lang.Object)
	     */
	    @Override
	    public void handleAction(final Object context) throws ApplicationException {
		if (context instanceof Register) {
		    handleAddLine((Register) context);
		}
	    }
	}, "list-add.png")); //$NON-NLS-1$

	addItem(new CheckedContextMenuItem(I18N.tr("RegisterTableMenu.deleteLine"), new Action() { //$NON-NLS-1$

	    /**
	     * @see de.willuhn.jameica.gui.Action#handleAction(java.lang.Object)
	     */
	    @Override
	    public void handleAction(final Object context) throws ApplicationException {

		if (context instanceof Register) {
		    handleRemoveLine(context);
		}
	    }
	}, "list-remove.png")); //$NON-NLS-1$

    }

    private void handleAddLine(final Register register) throws ApplicationException {
	try {
	    final TablePart table = this.controller.getRegisterTabelle();

	    for (int i = 0; i < table.getItems().size(); i++) {
		if (register.equals(table.getItems().get(i))) {

		    final DBService service = Settings.getDBService();
		    final Register reg = (RegisterImpl) service.createObject(Register.class, null);
		    reg.setOrdner(register.getOrdner());
		    table.addItem(reg, i + 1);
		    break;
		}
	    }
	} catch (final RemoteException e) {
	    throw new ApplicationException(I18N.tr("RegisterTableMenu.errorAdd"), e); //$NON-NLS-1$
	}

    }

    private void handleRemoveLine(final Object context) throws ApplicationException {
	try {
	    final TablePart table = this.controller.getRegisterTabelle();

	    if (table.getItems() instanceof List<?>) {
		final List<?> registerEntries = table.getItems();
		registerEntries.remove(context);

		table.removeAll();
		for (final Object entry : registerEntries) {
		    table.addItem(entry);
		}
	    }
	} catch (final RemoteException e) {
	    throw new ApplicationException(I18N.tr("RegisterTableMenu.errorDelete"), e); //$NON-NLS-1$
	}

    }

}
