/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.orverw.gui.views;

import java.rmi.RemoteException;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.TabFolder;

import de.frankmuenster.jameica.orverw.gui.controller.OrdnerBearbeitenController;
import de.frankmuenster.jameica.orverw.gui.input.ToolTipButton;
import de.frankmuenster.jameica.orverw.util.I18N;
import de.willuhn.jameica.gui.AbstractView;
import de.willuhn.jameica.gui.GUI;
import de.willuhn.jameica.gui.View;
import de.willuhn.jameica.gui.parts.ButtonArea;
import de.willuhn.jameica.gui.util.ScrolledContainer;
import de.willuhn.jameica.gui.util.SimpleContainer;
import de.willuhn.jameica.gui.util.TabGroup;
import de.willuhn.util.ApplicationException;

/**
 * View zum Bearbeiten eines Ordners
 *
 * @author Frank Mnster
 * @since 1.0
 */
public class OrdnerBearbeitenView extends AbstractView {

    /**
     * Unser Standartkonstruktor
     */
    public OrdnerBearbeitenView() {
	super();
    }

    /**
     * this method will be invoked when starting the view.
     *
     * @see de.willuhn.jameica.gui.AbstractView#bind()
     */
    @Override
    public void bind() throws RemoteException, ApplicationException {
	final View view = GUI.getView();
	final OrdnerBearbeitenController controller = new OrdnerBearbeitenController(this);
	if (controller.isNeuerOrdner()) {
	    view.setTitle(I18N.tr("OrdnerBearbeitenView.titleNewFolder")); //$NON-NLS-1$
	} else {
	    view.setTitle(I18N.tr("OrdnerBearbeitenView.titleEditFolder")); //$NON-NLS-1$
	}
	final TabFolder folder = new TabFolder(this.getParent(), SWT.NONE);
	folder.setLayoutData(new GridData(GridData.FILL_BOTH));
	final TabGroup labelTab = new TabGroup(folder, I18N.tr("OrdnerBearbeitenView.tabTextLabel"), false, 1); //$NON-NLS-1$
	final GridLayout gridLayout = new GridLayout(1, false);
	labelTab.getComposite().setLayout(gridLayout);
	final TabGroup contentTab = new TabGroup(folder, I18N.tr("OrdnerBearbeitenView.tabTextRegister")); //$NON-NLS-1$
	final ScrolledContainer labelScroll = new ScrolledContainer(labelTab.getComposite(), 1);
	final SimpleContainer registerTab = new SimpleContainer(contentTab.getComposite());
	new SimpleContainer(contentTab.getComposite()); // Empty Container to
							// fill 2nd column
	final SimpleContainer registerTabelle = new SimpleContainer(contentTab.getComposite(), true);
	labelScroll.addPart(controller.getOrdnerRuecken());
	registerTab.addHeadline(I18N.tr("OrdnerBearbeitenView.headlineRegister")); //$NON-NLS-1$
	registerTab.addPart(controller.getRegisterSettingsPart());
	registerTabelle.addPart(controller.getRegisterTabelle());
	final ButtonArea buttonArea1 = new ButtonArea();
	final List<ToolTipButton> registerBtns = controller.getRegisterButtons();
	for (final ToolTipButton button : registerBtns) {
	    buttonArea1.addButton(button);
	}
	contentTab.addButtonArea(buttonArea1);
	labelScroll.update();
	final ButtonArea buttonArea2 = new ButtonArea();
	buttonArea2.addButton(controller.getPrintButton());
	buttonArea2.addButton(controller.getSaveButton());
	buttonArea2.addButton(controller.getCancelEditButton());
	buttonArea2.paint(this.getParent());
    }

    /**
     * this method will be executed when exiting the view. You don't need to
     * dispose your widgets, the GUI controller will do this in a recursive way
     * for you.
     *
     * @see de.willuhn.jameica.gui.AbstractView#unbind()
     */
    @Override
    public void unbind() throws ApplicationException {
	// We've nothing to do here ;)
    }
}
