/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.jameica.orverw.parts.labelpart.buttons;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import de.frankmuenster.jameica.orverw.parts.labelpart.LabelPartSectionsEnum;
import de.frankmuenster.jameica.orverw.util.I18N;

/**
 * Erstellt eine Komponente mit Button zum Einstellen der
 * Labelhintergrundeinstellunugen. Dieses sind die Farbe des Hintergrundes,
 * Sichtbarkeit und Farbe der Trennlinien und die Sichtbarkeit der ID-Nummer.
 *
 * @author Frank Mnster
 * @since 1.0
 *
 */
public class LabelGeneralButtons extends AbstractButtonArea {

    /**
     * Konstruktor zum erstellen der Buttons.
     *
     * @param parent
     *            das SWT-Eltern_Composite in dem die Buttons gemalt werden
     * @param section
     *            der Bereich zu dem die Buttons geh&ouml;ren.
     *            (LabelPartSectionsEnum)
     * @param listener
     *            der Listener, der benachrichtigt wird, wenn ein Button
     *            gedr&uuml;ckt wurde.
     */
    public LabelGeneralButtons(final Composite parent, final LabelPartSectionsEnum section,
	    final LabelButtonListener listener) {

	super(parent, section, listener);

    }

    /**
     * @see AbstractButtonArea#drawButtons(Composite)
     */
    @Override
    protected final void drawButtons(final Composite parent) {

	final Composite container = new Composite(parent, SWT.BORDER);

	final RowLayout rowLayout = new RowLayout(SWT.VERTICAL);
	rowLayout.fill = true;
	rowLayout.spacing = 15;
	rowLayout.marginWidth = 20;
	rowLayout.marginTop = 10;
	rowLayout.marginBottom = 20;

	container.setLayout(rowLayout);

	final Label hgCfgLabel = new Label(container, SWT.NONE);
	hgCfgLabel.setText(
		I18N.tr("LabelGeneralButtons.background") + "-\n     " + I18N.tr("LabelGeneralButtons.settings")); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
	final RowData rowData = new RowData();
	rowData.height = 40;
	hgCfgLabel.setLayoutData(rowData);

	Button button = new Button(container, SWT.PUSH | SWT.CENTER);
	button.setText(I18N.tr("LabelGeneralButtons.bgColour")); //$NON-NLS-1$
	button.setToolTipText(I18N.tr("LabelGeneralButtons.bgColourTip")); //$NON-NLS-1$
	button.addSelectionListener(this);
	button.setData(LabelPartButtonsEnum.BACKGROUND_COLOUR);

	button = new Button(container, SWT.PUSH | SWT.CENTER);
	button.setText(I18N.tr("LabelGeneralButtons.lineVisible")); //$NON-NLS-1$
	button.setToolTipText(I18N.tr("LabelGeneralButtons.lineVisibleTip")); //$NON-NLS-1$
	button.addSelectionListener(this);
	button.setData(LabelPartButtonsEnum.BAR_VISIBLE);

	button = new Button(container, SWT.PUSH | SWT.CENTER);
	button.setText(I18N.tr("LabelGeneralButtons.lineColour")); //$NON-NLS-1$
	button.setToolTipText(I18N.tr("LabelGeneralButtons.lineColourTip")); //$NON-NLS-1$
	button.addSelectionListener(this);
	button.setData(LabelPartButtonsEnum.BAR_COLOUR);

	button = new Button(container, SWT.PUSH | SWT.CENTER);
	button.setText(I18N.tr("LabelGeneralButtons.showId")); //$NON-NLS-1$
	button.setToolTipText(I18N.tr("LabelGeneralButtons.showIdTip")); //$NON-NLS-1$
	button.addSelectionListener(this);
	button.setData(LabelPartButtonsEnum.ID_VISIBLE);

	container.pack();
	this.setSize(this.getSize().x + AbstractButtonArea.MARGIN, this.getSize().y + AbstractButtonArea.MARGIN);

    }

}
