/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.jameica.orverw.parts.labelpart.buttons;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;

import de.frankmuenster.jameica.orverw.parts.labelpart.LabelPartSectionsEnum;
import de.frankmuenster.jameica.orverw.util.I18N;
import de.willuhn.jameica.gui.util.SWTUtil;

/**
 * Die Buttons f&uuml;r die Farben und Schriftauswahl der Ordnerr&uuml;cken
 * Felder.
 *
 * @author Frank Mnster
 * @since 1.0
 */
public class LabelInputButtons extends AbstractButtonArea {

    /**
     * Gr&ouml;&szlig;e des Schrifttauswahl-Buttons
     */
    private static final Point FONT_BUTTON_SIZE = new Point(55, 25);
    /**
     * Gr&ouml;&szlig;e des T-Buttons
     */
    private static final Point ALIGN_BUTTON_SIZE = new Point(25, 25);

    /**
     * Konstruktor mit Angabe des SWT-Eltern-Composits, des zugeh&ouml;rigen
     * Eingabefeldes, und dem Listener.
     *
     * @param parent
     *            SWT-Eltern-Composit
     * @param section
     *            des zugeh&ouml;rigen Eingabefeldes als LabelPartSectionsEnum
     * @param listener
     *            der LabelButtonListener
     */
    public LabelInputButtons(final Composite parent, final LabelPartSectionsEnum section,
	    final LabelButtonListener listener) {

	super(parent, section, listener);

    }

    /**
     * @see AbstractButtonArea#drawButtons(Composite)
     */
    @Override
    protected final void drawButtons(final Composite composite) {

	final Button textFontButton = new Button(this, SWT.PUSH | SWT.CENTER);
	textFontButton.setLocation(AbstractButtonArea.MARGIN, AbstractButtonArea.MARGIN);
	textFontButton.setText(I18N.tr("LabelInputButtons.font")); //$NON-NLS-1$
	textFontButton.setSize(LabelInputButtons.FONT_BUTTON_SIZE);
	textFontButton.addSelectionListener(this);

	final Button textColorButton = new Button(this, SWT.PUSH | SWT.CENTER);
	textColorButton.setLocation(AbstractButtonArea.MARGIN + textFontButton.getSize().x + AbstractButtonArea.MARGIN,
		AbstractButtonArea.MARGIN);
	textColorButton.setImage(SWTUtil.getImage("colors-icon.png")); //$NON-NLS-1$
	textColorButton.setSize(LabelInputButtons.ALIGN_BUTTON_SIZE);
	textColorButton.addSelectionListener(this);

	final int secondRowTop = AbstractButtonArea.MARGIN + textFontButton.getBounds().y + textFontButton.getSize().y
		+ AbstractButtonArea.MARGIN;

	final Button textAlignLeft = new Button(this, SWT.PUSH | SWT.CENTER);
	textAlignLeft.setLocation(AbstractButtonArea.MARGIN, secondRowTop);
	textAlignLeft.setSize(LabelInputButtons.ALIGN_BUTTON_SIZE);
	textAlignLeft.setImage(SWTUtil.getImage("align_left.png")); //$NON-NLS-1$
	textAlignLeft.addSelectionListener(this);

	final Button textAlignCenter = new Button(this, SWT.CENTER);
	textAlignCenter.setLocation(
		textAlignLeft.getBounds().x + textAlignLeft.getBounds().width + AbstractButtonArea.MARGIN,
		secondRowTop);
	textAlignCenter.setSize(LabelInputButtons.ALIGN_BUTTON_SIZE);
	textAlignCenter.setImage(SWTUtil.getImage("align_center.png")); //$NON-NLS-1$
	textAlignCenter.addSelectionListener(this);

	final Button textAlignRight = new Button(this, SWT.CENTER);
	textAlignRight.setLocation(
		textAlignCenter.getBounds().x + textAlignCenter.getBounds().width + AbstractButtonArea.MARGIN,
		secondRowTop);
	textAlignRight.setSize(LabelInputButtons.ALIGN_BUTTON_SIZE);
	textAlignRight.setImage(SWTUtil.getImage("align_right.png")); //$NON-NLS-1$
	textAlignRight.addSelectionListener(this);

	this.pack();
	this.setSize(this.getSize().x + AbstractButtonArea.MARGIN, this.getSize().y + AbstractButtonArea.MARGIN);

    }

}
