/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.jameica.orverw.parts.labelpart.trenner;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import de.willuhn.jameica.gui.GUI;
import de.willuhn.jameica.gui.Part;

/**
 * Part das eine Linie auf dem OrdnerR&uuml;cken anzeigt
 *
 * @author Frank Mnster
 * @since 1.0
 */
public class BarTrenner implements Part {

    /**
     * Die Gr&ouml;&szlig;e des Parts
     */
    private transient Point size;

    /**
     * Oberer Abstand zur Linie
     */
    private transient int marginTop;

    /**
     * H&ouml;he der Linie
     */
    private transient int barHight;

    /**
     * Farbe der Linie
     */
    private transient Color barColor;

    /**
     * Farbe desd Hintergrundes
     */
    private transient Color background;

    /**
     * Sichtbarkeit der Linie. Hintergrund ist immer Sichbar!
     */
    private transient boolean visible;

    /**
     * Der Container, in dem alles gemalt wird
     */
    private transient Composite container;
    /**
     * Ein Label als Linie. Damit ist das &Auml;ndner einfacher.
     */
    private transient Label bar;

    /**
     * Konstruktor mit Angaben zur Gr&ouml;&szlig;e und Abst&auml;nden. Es
     * werden Standartfarbenm verwendet.
     *
     * @param size
     *            die Gr&ouml;&szlig;e des Containers
     * @param marginTop
     *            der obere Abstand zur Linie
     * @param barHight
     *            die H&ouml;he der Linie
     * @throws NullPointerException
     */
    public BarTrenner(final Point size, final int marginTop, final int barHight) {
	this(size, marginTop, barHight, null, null);
    }

    /**
     * Konstruktor mit Angaben zur Gr&ouml;&szlig;e, Abst&auml;nden und Farben
     *
     * @param size
     *            die Gr&ouml;&szlig;e des Containers
     * @param marginTop
     *            der obere Abstand zur Linie
     * @param barHight
     *            die H&ouml;he der Linie
     * @param barColor
     *            die Farbe der Linien
     * @param background
     *            die Farbe des Hintergrundes
     * @throws NullPointerException
     */
    public BarTrenner(final Point size, final int marginTop, final int barHight, final Color barColor,
	    final Color background) {
	this(size, marginTop, barHight, barColor, background, true);
    }

    /**
     * Konstruktor mit Angaben zur Gr&ouml;&szlig;e, Abst&auml;nden und Farben
     *
     * @param size
     *            die Gr&ouml;&szlig;e des Containers
     * @param marginTop
     *            der obere Abstand zur Linie
     * @param barHight
     *            die H&ouml;he der Linie
     * @param barColor
     *            die Farbe der Linien
     * @param background
     *            die Farbe des Hintergrundes
     * @param visible
     *            die Sichbarkeit der Linie
     * @throws NullPointerException
     */
    public BarTrenner(final Point size, final int marginTop, final int barHight, final Color barColor,
	    final Color background, final boolean visible) {

	// null checks
	if (size == null) {
	    throw new IllegalArgumentException("Size cannot be Null"); //$NON-NLS-1$
	}

	this.size = size;
	if (barHight > 0 && barHight < this.size.y) {
	    this.barHight = barHight;
	} else {
	    this.barHight = size.y / 2;
	}

	if (marginTop < this.size.y + barHight) {
	    this.marginTop = marginTop;
	} else {
	    this.marginTop = this.size.y - barHight;
	}

	if (barColor == null) {
	    this.barColor = barColor;
	} else {
	    this.barColor = new Color(GUI.getDisplay(), 0, 0, 240);
	}

	if (background == null) {
	    this.background = background;
	} else {
	    this.background = new Color(GUI.getDisplay(), 255, 255, 224);
	}

	this.visible = visible;

    }

    /**
     * @see de.willuhn.jameica.gui.Part#paint(org.eclipse.swt.widgets.Composite)
     */
    @Override
    public void paint(final Composite parent) {

	this.container = new Composite(parent, SWT.NONE);

	final RowLayout rowLayout = new RowLayout(SWT.VERTICAL);
	this.container.setLayout(rowLayout);
	final int marginLeftRight = (int) (this.size.x * 0.05);
	rowLayout.center = true;
	rowLayout.marginTop = this.marginTop;
	rowLayout.marginLeft = marginLeftRight;

	final GridData gridData = new GridData();
	gridData.heightHint = this.size.y;
	gridData.widthHint = this.size.x;
	this.container.setLayoutData(gridData);
	this.container.setBackground(this.background);

	if (this.bar == null) {
	    this.bar = new Label(this.container, SWT.NONE);
	}

	final RowData rowData = new RowData();
	rowData.height = this.barHight;
	rowData.width = this.size.x - 2 * marginLeftRight;
	this.bar.setLayoutData(rowData);

	this.bar.setBackground(this.barColor);

	// Set the bar visible
	this.bar.setVisible(this.visible);

    }

    /**
     * @param background
     *            das zu setzende Objekt background
     */
    public void setBackground(final Color background) {
	if (background != null) {
	    this.background = background;
	    if (this.container != null) {
		this.container.setBackground(background);
	    }
	}
    }

    /**
     * @param barColor
     *            das zu setzende Objekt barColor
     */
    public void setBarColor(final Color barColor) {
	if (barColor != null) {
	    this.barColor = barColor;
	    if (this.bar != null) {
		this.bar.setBackground(barColor);
	    }
	}

    }

    /**
     * Setzt die Sichbarbeit der Linie
     *
     * @param visible
     *            die Sichbarbeit der Linie
     */
    public void setVisible(final boolean visible) {
	this.visible = visible;
	if (this.bar != null) {
	    this.bar.setVisible(visible);
	}
    }

}
