/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.jameica.orverw.print;

import org.eclipse.nebula.paperclips.core.Print;
import org.eclipse.nebula.paperclips.core.page.PageNumberPageDecoration;
import org.eclipse.nebula.paperclips.core.page.PagePrint;
import org.eclipse.nebula.paperclips.core.page.SimplePageDecoration;
import org.eclipse.nebula.paperclips.core.text.TextPrint;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.FontData;

import de.willuhn.jameica.gui.util.Font;
import de.willuhn.util.ApplicationException;

/**
 * Abstrakte Klasse die ein Print-Interface bereit stellt.
 *
 * @author Frank Mnster
 * @since 1.0
 */
public abstract class AbstractPrint {

    /**
     * Der Schrifttyp des Titelfeldes
     */
    protected static final FontData FONT_BOLD = Font.BOLD.getSWTFont().getFontData()[0];

    /**
     * Die System-Standartschrift
     */
    protected static final FontData FONT_NORMAL = Font.SMALL.getSWTFont().getFontData()[0];

    /**
     * Die System-Standartschrift in FETT
     */
    protected static final FontData FONT_NORMAL_BOLD = new FontData(AbstractPrint.FONT_NORMAL.getName(),
            AbstractPrint.FONT_NORMAL.getHeight(), SWT.BOLD);

    /**
     * Die System-Standartschrift in KLEIN
     */
    protected static final FontData FONT_TINY = new FontData(AbstractPrint.FONT_NORMAL.getName(),
            AbstractPrint.FONT_NORMAL.getHeight() - 2, SWT.NORMAL);

    /**
     * Die System-Standartschrift in KLEIN und FETT
     */
    protected static final FontData FONT_TINY_BOLD = new FontData(AbstractPrint.FONT_TINY.getName(),
            AbstractPrint.FONT_TINY.getHeight(), SWT.BOLD);

    /**
     * Standartkonstruktor
     */
    public AbstractPrint() {

        // intentionally left blank
    }

    /**
     * Erstellt und liefert das Print-Objekt
     *
     * @return Das Print-Objekt
     * @throws ApplicationException
     */
    public Print createPrint() throws ApplicationException {

        final Print content = this.getPrintContent();
        final PagePrint page = new PagePrint(content);
        page.setHeader(new SimplePageDecoration(new TextPrint(this.getTitle(), SWT.CENTER)));
        page.setHeaderGap(5);
        page.setFooterGap(5);
        final PageNumberPageDecoration footer = new PageNumberPageDecoration(SWT.RIGHT);
        footer.setFontData(AbstractPrint.FONT_TINY);
        page.setFooter(footer);
        // Falls eine Sub-Klasse noch was ndern will, jetzt gilt's
        this.customise(page);
        return page;
    }

    /**
     * Liefert den Titel des Drucks als String
     *
     * @return Der Titel des Drucks als String
     */
    public abstract String getTitle();

    /**
     * Hier kann eine Sub-Klasse das Print-Objekt nochmal &auml;ndern.
     *
     * @param page
     *            Der ganze Ausdruck als PrintPage-Objekt
     * @throws ApplicationException
     */
    protected abstract void customise(PagePrint page) throws ApplicationException;

    /**
     * Liefert den Druckinhalt als Print-Objekt
     *
     * @return Print mit Druckinhalt
     * @throws ApplicationException
     */
    protected abstract Print getPrintContent() throws ApplicationException;
}
